Interface SqlCommenterCustomizer


public interface SqlCommenterCustomizer
Customize configuration for SqlCommenterBuilder. This lets extensions configure different propagators and decide whether to prepend or append the sqlcommenter comment based on the database where the query is executed.

This class is internal and is hence not for public use. Its APIs are unstable and can change at any time.

  • Method Summary

    Modifier and Type
    Method
    Description
    void
    customize(io.opentelemetry.instrumentation.api.incubator.semconv.db.internal.SqlCommenterBuilder builder)
    Customize the given SqlCommenterBuilder.
  • Method Details

    • customize

      void customize(io.opentelemetry.instrumentation.api.incubator.semconv.db.internal.SqlCommenterBuilder builder)
      Customize the given SqlCommenterBuilder.