Class SqlCommenterCustomizerHolder

java.lang.Object
io.opentelemetry.javaagent.bootstrap.internal.sqlcommenter.SqlCommenterCustomizerHolder

public final class SqlCommenterCustomizerHolder extends Object
This class is internal and is hence not for public use. Its APIs are unstable and can change at any time.