Enum ExperimentalInstrumentationModule.HelperClassStrategy
java.lang.Object
java.lang.Enum<ExperimentalInstrumentationModule.HelperClassStrategy>
io.opentelemetry.javaagent.extension.instrumentation.internal.ExperimentalInstrumentationModule.HelperClassStrategy
- All Implemented Interfaces:
Serializable,Comparable<ExperimentalInstrumentationModule.HelperClassStrategy>,java.lang.constant.Constable
- Enclosing interface:
ExperimentalInstrumentationModule
public static enum ExperimentalInstrumentationModule.HelperClassStrategy
extends Enum<ExperimentalInstrumentationModule.HelperClassStrategy>
This class is internal and is hence not for public use. Its APIs are unstable and can change at
any time.
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionDepending on whether the instrumentation uses inline advice or not, helper classes are either loaded in the same classloader as the instrumented library, or into an isolated classloader.Helper classes are loaded in the same classloader as the instrumented library, and are visible to the application.Helper classes are loaded into an isolated classloader, and aren't visible to the application. -
Method Summary
Modifier and TypeMethodDescriptionReturns the enum constant of this type with the specified name.values()Returns an array containing the constants of this enum type, in the order they are declared.
-
Enum Constant Details
-
DEFAULT
Depending on whether the instrumentation uses inline advice or not, helper classes are either loaded in the same classloader as the instrumented library, or into an isolated classloader. -
INJECTED
Helper classes are loaded in the same classloader as the instrumented library, and are visible to the application. -
ISOLATED
Helper classes are loaded into an isolated classloader, and aren't visible to the application.
-
-
Method Details
-
values
Returns an array containing the constants of this enum type, in the order they are declared.- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-