Index
All Classes and Interfaces|All Packages|Constant Field Values
A
- addCache(Cache<ClassLoader, ?>) - Static method in class io.opentelemetry.javaagent.bootstrap.internal.ClassLoaderMatcherCacheHolder
- afterAgent(AutoConfiguredOpenTelemetrySdk) - Method in interface io.opentelemetry.javaagent.extension.AgentListener
-
Runs after instrumentations are added to
AgentBuilderand after the agent is installed on anInstrumentation. - AgentCommonConfig - Class in io.opentelemetry.javaagent.bootstrap.internal
-
This class is internal and is hence not for public use.
- AgentDistributionConfig - Class in io.opentelemetry.javaagent.extension.instrumentation.internal
-
Javaagent distribution-specific configuration.
- AgentElementMatchers - Class in io.opentelemetry.javaagent.extension.matcher
-
This class is a supplement to ByteBuddy's
ElementMatchers- it provides some custom matcher implementations that might be useful for instrumentation purposes. - AgentListener - Interface in io.opentelemetry.javaagent.extension
-
AgentListenercan be used to execute code after Java agent installation. - agentPackagesToHide() - Method in interface io.opentelemetry.javaagent.extension.instrumentation.internal.ExperimentalInstrumentationModule
-
Some instrumentations need to invoke classes which are present both in the agent classloader and the instrumented application classloader.
- allowClass(String) - Method in interface io.opentelemetry.javaagent.extension.ignore.IgnoredTypesBuilder
-
Allow the class or package specified by
classNameOrPrefixto be instrumented. - allowClassLoader(String) - Method in interface io.opentelemetry.javaagent.extension.ignore.IgnoredTypesBuilder
-
Allow the class loader specified by
classNameOrPrefixto be instrumented. - appendHeader(RESPONSE, String, String) - Method in interface io.opentelemetry.javaagent.bootstrap.http.HttpServerResponseMutator
- applyAdviceToMethod(ElementMatcher<? super MethodDescription>, String) - Method in interface io.opentelemetry.javaagent.extension.instrumentation.TypeTransformer
-
Apply the advice class named
adviceClassNameto the instrumented type methods that matchmethodMatcher. - applyAdviceToMethod(ElementMatcher<? super MethodDescription>, Function<Advice.WithCustomMapping, Advice.WithCustomMapping>, String) - Method in interface io.opentelemetry.javaagent.extension.instrumentation.TypeTransformer
-
Apply the advice class named
adviceClassNameto the instrumented type methods that matchmethodMatcher. - applyTransformer(AgentBuilder.Transformer) - Method in interface io.opentelemetry.javaagent.extension.instrumentation.TypeTransformer
-
Apply a custom ByteBuddy
AgentBuilder.Transformerto the instrumented type. - AsmApi - Class in io.opentelemetry.javaagent.extension.instrumentation.internal
-
This class is internal and is hence not for public use.
B
- baggageFromContext(Context) - Static method in class io.opentelemetry.javaagent.bootstrap.Java8BytecodeBridge
C
- CallDepth - Class in io.opentelemetry.javaagent.bootstrap
-
A utility to track nested calls in an instrumentation.
- classLoaderMatcher() - Method in class io.opentelemetry.javaagent.extension.instrumentation.InstrumentationModule
-
An instrumentation module can implement this method to make sure that the class loader contains the particular library version.
- ClassLoaderMatcherCacheHolder - Class in io.opentelemetry.javaagent.bootstrap.internal
-
A holder of all ClassLoaderMatcher caches.
- classLoaderOptimization() - Method in interface io.opentelemetry.javaagent.extension.instrumentation.TypeInstrumentation
-
An optimization to short circuit matching in the case where the instrumented library is not even present on the class path.
- configure(IgnoredTypesBuilder) - Method in interface io.opentelemetry.javaagent.extension.ignore.IgnoredTypesConfigurer
-
Configure the passed
builderand define which classes should be ignored when instrumenting. - configure(IgnoredTypesBuilder, ConfigProperties) - Method in interface io.opentelemetry.javaagent.extension.ignore.IgnoredTypesConfigurer
-
Deprecated.
- ConfiguredResourceAttributesHolder - Class in io.opentelemetry.javaagent.bootstrap.internal
-
This class is internal and is hence not for public use.
- controllerTelemetryEnabled() - Method in class io.opentelemetry.javaagent.bootstrap.internal.ExperimentalConfig
- create() - Static method in class io.opentelemetry.javaagent.extension.instrumentation.internal.AgentDistributionConfig
-
Creates a new instance for testing or fallback configuration scenarios.
- create(DefaultHttpClientInstrumenterBuilder<REQUEST, RESPONSE>) - Static method in class io.opentelemetry.javaagent.bootstrap.internal.JavaagentHttpClientInstrumenters
- create(DefaultHttpServerInstrumenterBuilder<REQUEST, RESPONSE>) - Static method in class io.opentelemetry.javaagent.bootstrap.internal.JavaagentHttpServerInstrumenters
- create(DefaultHttpServerInstrumenterBuilder<REQUEST, RESPONSE>, Consumer<InstrumenterBuilder<REQUEST, RESPONSE>>) - Static method in class io.opentelemetry.javaagent.bootstrap.internal.JavaagentHttpServerInstrumenters
- create(String, HttpClientAttributesGetter<REQUEST, RESPONSE>) - Static method in class io.opentelemetry.javaagent.bootstrap.internal.JavaagentHttpClientInstrumenters
- create(String, HttpClientAttributesGetter<REQUEST, RESPONSE>, TextMapSetter<REQUEST>) - Static method in class io.opentelemetry.javaagent.bootstrap.internal.JavaagentHttpClientInstrumenters
- create(String, HttpClientAttributesGetter<REQUEST, RESPONSE>, TextMapSetter<REQUEST>, Consumer<InstrumenterBuilder<REQUEST, RESPONSE>>) - Static method in class io.opentelemetry.javaagent.bootstrap.internal.JavaagentHttpClientInstrumenters
- create(String, HttpServerAttributesGetter<REQUEST, RESPONSE>, TextMapGetter<REQUEST>) - Static method in class io.opentelemetry.javaagent.bootstrap.internal.JavaagentHttpServerInstrumenters
- create(String, HttpServerAttributesGetter<REQUEST, RESPONSE>, TextMapGetter<REQUEST>, Consumer<InstrumenterBuilder<REQUEST, RESPONSE>>) - Static method in class io.opentelemetry.javaagent.bootstrap.internal.JavaagentHttpServerInstrumenters
- currentContext() - Static method in class io.opentelemetry.javaagent.bootstrap.Java8BytecodeBridge
-
Calls
Context.current(). - currentSpan() - Static method in class io.opentelemetry.javaagent.bootstrap.Java8BytecodeBridge
-
Calls
Span.current(). - customize(Context, RESPONSE, HttpServerResponseMutator<RESPONSE>) - Method in interface io.opentelemetry.javaagent.bootstrap.http.HttpServerResponseCustomizer
-
Called for each HTTP server response with its SERVER span context provided.
- customize(SqlCommenterBuilder) - Method in interface io.opentelemetry.javaagent.bootstrap.internal.sqlcommenter.SqlCommenterCustomizer
-
Customize the given
SqlCommenterBuilder.
D
- decrementAndGet() - Method in class io.opentelemetry.javaagent.bootstrap.CallDepth
-
Decrement the current call depth and return the current value.
- DEFAULT - Enum constant in enum io.opentelemetry.javaagent.extension.instrumentation.internal.ExperimentalInstrumentationModule.HelperClassStrategy
-
Depending on whether the instrumentation uses inline advice or not, helper classes are either loaded in the same classloader as the instrumented library, or into an isolated classloader.
- defaultEnabled() - Method in class io.opentelemetry.javaagent.extension.instrumentation.InstrumentationModule
-
Allows instrumentation modules to disable themselves by default, or to additionally disable themselves on some other condition.
- defaultEnabled(ConfigProperties) - Method in class io.opentelemetry.javaagent.extension.instrumentation.InstrumentationModule
-
Deprecated.Use
InstrumentationModule.defaultEnabled()instead. - DelegatingMatcher - Interface in io.opentelemetry.javaagent.extension.matcher.internal
-
Interface for extracting the matcher that the given matcher delegates to.
- DelegatingSuperTypeMatcher - Interface in io.opentelemetry.javaagent.extension.matcher.internal
-
Marker interface for delegating matchers that match based on the type hierarchy.
- DeprecatedInstrumentationNames - Class in io.opentelemetry.javaagent.extension.instrumentation.internal
-
Helper for
InstrumentationModules whose names have been renamed: expands names containing the inline marker"<current>|deprecated:<old>"into the current name followed by the deprecated name.
E
- EarlyInstrumentationModule - Interface in io.opentelemetry.javaagent.extension.instrumentation.internal
-
Marker interface for instrumentation modules whose virtual fields should be set up before OpenTelemetry SDK is initialized.
- expandDeprecatedNames(String...) - Static method in class io.opentelemetry.javaagent.extension.instrumentation.internal.DeprecatedInstrumentationNames
-
Expands names containing
"<current>|deprecated:<old>"into the current name followed by the deprecated name. - ExperimentalConfig - Class in io.opentelemetry.javaagent.bootstrap.internal
-
This class is internal and is hence not for public use.
- ExperimentalConfig(OpenTelemetry) - Constructor for class io.opentelemetry.javaagent.bootstrap.internal.ExperimentalConfig
- ExperimentalInstrumentationModule - Interface in io.opentelemetry.javaagent.extension.instrumentation.internal
-
This class is internal and is hence not for public use.
- ExperimentalInstrumentationModule.HelperClassStrategy - Enum in io.opentelemetry.javaagent.extension.instrumentation.internal
-
This class is internal and is hence not for public use.
- exposedClassNames() - Method in interface io.opentelemetry.javaagent.extension.instrumentation.internal.ExperimentalInstrumentationModule
-
Returns a list of instrumentation helper classes that are exposed to the application class loader.
- extendsClass(ElementMatcher<TypeDescription>) - Static method in class io.opentelemetry.javaagent.extension.matcher.AgentElementMatchers
-
Matches a type that extends a class (directly or indirectly) that matches the provided
matcher.
F
- forClass(Class<?>) - Static method in class io.opentelemetry.javaagent.bootstrap.CallDepth
-
Return the current call depth for a given class (not method; we want to be able to track calls between different methods in a class).
- fromConfigProperties(ConfigProperties) - Static method in class io.opentelemetry.javaagent.extension.instrumentation.internal.AgentDistributionConfig
-
Creates a new instance from ConfigProperties.
G
- get() - Static method in class io.opentelemetry.javaagent.bootstrap.internal.AgentCommonConfig
- get() - Static method in class io.opentelemetry.javaagent.bootstrap.internal.ExperimentalConfig
-
Returns the global agent configuration.
- get() - Static method in class io.opentelemetry.javaagent.bootstrap.internal.InClassLoaderMatcher
-
Returns whether the ClassLoaderMatcher is currently executing.
- get() - Static method in class io.opentelemetry.javaagent.extension.instrumentation.internal.AgentDistributionConfig
- getAdditionalHelperClassNames() - Method in class io.opentelemetry.javaagent.extension.instrumentation.InstrumentationModule
-
Returns a list of additional instrumentation helper classes, which are not automatically detected during compile time.
- getAndIncrement() - Method in class io.opentelemetry.javaagent.bootstrap.CallDepth
-
Increment the current call depth and return the previous value.
- getAndSet(boolean) - Static method in class io.opentelemetry.javaagent.bootstrap.internal.InClassLoaderMatcher
-
WARNING This should not be used by instrumentation.
- getAttributeValue(String) - Static method in class io.opentelemetry.javaagent.bootstrap.internal.ConfiguredResourceAttributesHolder
- getCustomizer() - Static method in class io.opentelemetry.javaagent.bootstrap.http.HttpServerResponseCustomizerHolder
- getCustomizer() - Static method in class io.opentelemetry.javaagent.bootstrap.internal.sqlcommenter.SqlCommenterCustomizerHolder
- getDelegate() - Method in interface io.opentelemetry.javaagent.extension.matcher.internal.DelegatingMatcher
-
Returns the matcher that the current matcher delegates to.
- getExcludeClasses() - Method in class io.opentelemetry.javaagent.extension.instrumentation.internal.AgentDistributionConfig
- getExcludeClassLoaders() - Method in class io.opentelemetry.javaagent.extension.instrumentation.internal.AgentDistributionConfig
- getInstrumentationModule() - Method in interface io.opentelemetry.javaagent.extension.instrumentation.internal.EarlyInstrumentationModule
- getMessagingHeaders() - Method in class io.opentelemetry.javaagent.bootstrap.internal.ExperimentalConfig
- getModuleGroup() - Method in interface io.opentelemetry.javaagent.extension.instrumentation.internal.ExperimentalInstrumentationModule
-
By default every InstrumentationModule is loaded by an isolated classloader, even if multiple modules instrument the same application classloader.
- getResourceAttributes() - Static method in class io.opentelemetry.javaagent.bootstrap.internal.ConfiguredResourceAttributesHolder
H
- hasClassesNamed(String...) - Static method in class io.opentelemetry.javaagent.extension.matcher.AgentElementMatchers
-
Matches a class loader that contains all classes that are passed as the
classNamesparameter. - hasSuperMethod(ElementMatcher<? super MethodDescription>) - Static method in class io.opentelemetry.javaagent.extension.matcher.AgentElementMatchers
-
Matches a method and all its declarations up the class hierarchy including interfaces using provided matcher.
- hasSuperType(ElementMatcher<TypeDescription>) - Static method in class io.opentelemetry.javaagent.extension.matcher.AgentElementMatchers
-
Matches a type that extends or implements a type (directly or indirectly) that matches the provided
matcher. - helperClassStrategy() - Method in interface io.opentelemetry.javaagent.extension.instrumentation.internal.ExperimentalInstrumentationModule
-
Allows instrumentation modules to choose whether the helper classes should be injected into the same class loader as the instrumented library, or into an isolated class loader.
- HelperResourceBuilder - Interface in io.opentelemetry.javaagent.extension.instrumentation
- HttpServerResponseCustomizer - Interface in io.opentelemetry.javaagent.bootstrap.http
-
HttpServerResponseCustomizercan be used to execute code after an HTTP server response is created for the purpose of mutating the response in some way, such as appending headers, that may depend on the context of the SERVER span. - HttpServerResponseCustomizerHolder - Class in io.opentelemetry.javaagent.bootstrap.http
-
Holds the currently active response customizer.
- HttpServerResponseMutator<RESPONSE> - Interface in io.opentelemetry.javaagent.bootstrap.http
-
Provides the ability to mutate an instrumentation library specific response.
I
- ignoreClass(String) - Method in interface io.opentelemetry.javaagent.extension.ignore.IgnoredTypesBuilder
-
Ignore the class or package specified by
classNameOrPrefixand exclude it from being instrumented. - ignoreClassLoader(String) - Method in interface io.opentelemetry.javaagent.extension.ignore.IgnoredTypesBuilder
-
Ignore the class loader specified by
classNameOrPrefixand exclude it from being instrumented. - IgnoredTypesBuilder - Interface in io.opentelemetry.javaagent.extension.ignore
-
This interface defines different ways to ignore/allow instrumenting classes or packages.
- IgnoredTypesConfigurer - Interface in io.opentelemetry.javaagent.extension.ignore
-
An
IgnoredTypesConfigurercan be used to augment built-in instrumentation restrictions: ignore some classes and exclude them from being instrumented, or explicitly allow them to be instrumented if the agent ignored them by default. - ignoreTaskClass(String) - Method in interface io.opentelemetry.javaagent.extension.ignore.IgnoredTypesBuilder
-
Ignore the Java concurrent task class specified by
classNameOrPrefixand exclude it from being instrumented. - implementsInterface(ElementMatcher<TypeDescription>) - Static method in class io.opentelemetry.javaagent.extension.matcher.AgentElementMatchers
-
Matches a type that implements an interface (directly or indirectly) that matches the provided
matcher. - InClassLoaderMatcher - Class in io.opentelemetry.javaagent.bootstrap.internal
-
This class is internal and is hence not for public use.
- initialize(Attributes) - Static method in class io.opentelemetry.javaagent.bootstrap.internal.ConfiguredResourceAttributesHolder
- INJECTED - Enum constant in enum io.opentelemetry.javaagent.extension.instrumentation.internal.ExperimentalInstrumentationModule.HelperClassStrategy
-
Helper classes are loaded in the same classloader as the instrumented library, and are visible to the application.
- injectedClassNames() - Method in interface io.opentelemetry.javaagent.extension.instrumentation.internal.ExperimentalInstrumentationModule
-
Returns a list of helper classes that will be defined in the class loader of the instrumented library.
- InstrumentationModule - Class in io.opentelemetry.javaagent.extension.instrumentation
-
Instrumentation module groups several connected
TypeInstrumentations together, sharing class loader matcher, helper classes, muzzle safety checks, etc. - InstrumentationModule(String, String...) - Constructor for class io.opentelemetry.javaagent.extension.instrumentation.InstrumentationModule
-
Creates an instrumentation module.
- instrumentationName() - Method in class io.opentelemetry.javaagent.extension.instrumentation.InstrumentationModule
-
Returns the main instrumentation name.
- instrumentationNames() - Method in class io.opentelemetry.javaagent.extension.instrumentation.InstrumentationModule
-
Returns all instrumentation names assigned to this module.
- invalidateAllCachesForClassLoader(ClassLoader) - Static method in class io.opentelemetry.javaagent.bootstrap.internal.ClassLoaderMatcherCacheHolder
- io.opentelemetry.javaagent.bootstrap - package io.opentelemetry.javaagent.bootstrap
- io.opentelemetry.javaagent.bootstrap.http - package io.opentelemetry.javaagent.bootstrap.http
- io.opentelemetry.javaagent.bootstrap.internal - package io.opentelemetry.javaagent.bootstrap.internal
- io.opentelemetry.javaagent.bootstrap.internal.sqlcommenter - package io.opentelemetry.javaagent.bootstrap.internal.sqlcommenter
- io.opentelemetry.javaagent.extension - package io.opentelemetry.javaagent.extension
- io.opentelemetry.javaagent.extension.ignore - package io.opentelemetry.javaagent.extension.ignore
- io.opentelemetry.javaagent.extension.instrumentation - package io.opentelemetry.javaagent.extension.instrumentation
- io.opentelemetry.javaagent.extension.instrumentation.internal - package io.opentelemetry.javaagent.extension.instrumentation.internal
- io.opentelemetry.javaagent.extension.matcher - package io.opentelemetry.javaagent.extension.matcher
- io.opentelemetry.javaagent.extension.matcher.internal - package io.opentelemetry.javaagent.extension.matcher.internal
- isForceSynchronousAgentListeners() - Method in class io.opentelemetry.javaagent.extension.instrumentation.internal.AgentDistributionConfig
- isHelperClass(String) - Method in class io.opentelemetry.javaagent.extension.instrumentation.InstrumentationModule
-
Instrumentation modules can override this method to specify additional packages (or classes) that should be treated as "library instrumentation" packages.
- isIndyEnabled() - Method in class io.opentelemetry.javaagent.extension.instrumentation.internal.AgentDistributionConfig
- isIndyModule() - Method in class io.opentelemetry.javaagent.extension.instrumentation.InstrumentationModule
-
Deprecated.
- isInstrumentationDefaultEnabled() - Method in class io.opentelemetry.javaagent.extension.instrumentation.internal.AgentDistributionConfig
-
Returns whether instrumentations are enabled by default.
- isInstrumentationEnabled(Iterable<String>, boolean) - Method in class io.opentelemetry.javaagent.extension.instrumentation.internal.AgentDistributionConfig
-
Returns whether any of the given instrumentations is enabled, falling back to
defaultEnabledif none of the names are explicitly configured. - isInstrumentationEnabled(String) - Method in class io.opentelemetry.javaagent.extension.instrumentation.internal.AgentDistributionConfig
-
Returns whether the given instrumentation is enabled, falling back to
AgentDistributionConfig.isInstrumentationDefaultEnabled()if not explicitly configured. - isInstrumentationEnabled(String, boolean) - Method in class io.opentelemetry.javaagent.extension.instrumentation.internal.AgentDistributionConfig
-
Returns whether the given instrumentation is enabled, falling back to
defaultEnabledif not explicitly configured. - ISOLATED - Enum constant in enum io.opentelemetry.javaagent.extension.instrumentation.internal.ExperimentalInstrumentationModule.HelperClassStrategy
-
Helper classes are loaded into an isolated classloader, and aren't visible to the application.
J
- Java8BytecodeBridge - Class in io.opentelemetry.javaagent.bootstrap
-
A helper for accessing methods that rely on new Java 8 bytecode features such as calling a static interface methods.
- JavaagentHttpClientInstrumenters - Class in io.opentelemetry.javaagent.bootstrap.internal
-
This class is internal and is hence not for public use.
- JavaagentHttpServerInstrumenters - Class in io.opentelemetry.javaagent.bootstrap.internal
-
This class is internal and is hence not for public use.
- jpmsModulesToOpen() - Method in interface io.opentelemetry.javaagent.extension.instrumentation.internal.ExperimentalInstrumentationModule
-
Some instrumentation need to access JPMS modules that are not accessible by default, this method provides a way to access those classes like the "--add-opens" JVM command.
M
- messagingReceiveInstrumentationEnabled() - Method in class io.opentelemetry.javaagent.bootstrap.internal.ExperimentalConfig
- methodIsDeclaredByType(ElementMatcher<? super TypeDescription>) - Static method in class io.opentelemetry.javaagent.extension.matcher.AgentElementMatchers
-
Matches method's declaring class against a given type matcher.
R
- register(String) - Method in interface io.opentelemetry.javaagent.extension.instrumentation.HelperResourceBuilder
-
Registers a resource to be injected in the user's class loader.
- register(String, String) - Method in interface io.opentelemetry.javaagent.extension.instrumentation.HelperResourceBuilder
-
Registers a resource to be injected in the user's class loader.
- registerForAllClassLoaders(String) - Method in interface io.opentelemetry.javaagent.extension.instrumentation.HelperResourceBuilder
-
Registers a resource to be injected into all class loaders in the instrumented application.
- registerForAllClassLoaders(String, String) - Method in interface io.opentelemetry.javaagent.extension.instrumentation.HelperResourceBuilder
-
Registers a resource to be injected into all class loaders in the instrumented application.
- registerHelperResources(HelperResourceBuilder) - Method in class io.opentelemetry.javaagent.extension.instrumentation.InstrumentationModule
-
Register resource names to inject into the user's class loader.
- resetForTest() - Static method in class io.opentelemetry.javaagent.extension.instrumentation.internal.AgentDistributionConfig
- rootContext() - Static method in class io.opentelemetry.javaagent.bootstrap.Java8BytecodeBridge
-
Calls
Context.root().
S
- set(boolean) - Static method in class io.opentelemetry.javaagent.bootstrap.internal.InClassLoaderMatcher
-
WARNING This should not be used by instrumentation.
- set(AgentDistributionConfig) - Static method in class io.opentelemetry.javaagent.extension.instrumentation.internal.AgentDistributionConfig
- setCustomizer(HttpServerResponseCustomizer) - Static method in class io.opentelemetry.javaagent.bootstrap.http.HttpServerResponseCustomizerHolder
- setCustomizer(SqlCommenterCustomizer) - Static method in class io.opentelemetry.javaagent.bootstrap.internal.sqlcommenter.SqlCommenterCustomizerHolder
- spanFromContext(Context) - Static method in class io.opentelemetry.javaagent.bootstrap.Java8BytecodeBridge
-
Calls
Span.fromContext(Context). - SqlCommenterCustomizer - Interface in io.opentelemetry.javaagent.bootstrap.internal.sqlcommenter
-
Customize configuration for
SqlCommenterBuilder. - SqlCommenterCustomizerHolder - Class in io.opentelemetry.javaagent.bootstrap.internal.sqlcommenter
-
This class is internal and is hence not for public use.
T
- transform(TypeTransformer) - Method in interface io.opentelemetry.javaagent.extension.instrumentation.TypeInstrumentation
-
Define transformations that should be applied to classes matched by
TypeInstrumentation.typeMatcher(), for example: apply advice classes to chosen methods (applyAdviceToMethod(ElementMatcher, String). - TypeInstrumentation - Interface in io.opentelemetry.javaagent.extension.instrumentation
-
Interface representing a single type instrumentation.
- typeInstrumentations() - Method in class io.opentelemetry.javaagent.extension.instrumentation.InstrumentationModule
-
Returns a list of all individual type instrumentation in this module.
- typeMatcher() - Method in interface io.opentelemetry.javaagent.extension.instrumentation.TypeInstrumentation
-
Returns a type matcher defining which classes should undergo transformations defined in the
TypeInstrumentation.transform(TypeTransformer)method. - TypeTransformer - Interface in io.opentelemetry.javaagent.extension.instrumentation
-
This interface represents type transformations that can be applied to a type instrumented using
TypeInstrumentation.
V
- valueOf(String) - Static method in enum io.opentelemetry.javaagent.extension.instrumentation.internal.ExperimentalInstrumentationModule.HelperClassStrategy
-
Returns the enum constant of this type with the specified name.
- values() - Static method in enum io.opentelemetry.javaagent.extension.instrumentation.internal.ExperimentalInstrumentationModule.HelperClassStrategy
-
Returns an array containing the constants of this enum type, in the order they are declared.
- VERSION - Static variable in class io.opentelemetry.javaagent.extension.instrumentation.internal.AsmApi
- viewTelemetryEnabled() - Method in class io.opentelemetry.javaagent.bootstrap.internal.ExperimentalConfig
All Classes and Interfaces|All Packages|Constant Field Values
IgnoredTypesConfigurer.configure(IgnoredTypesBuilder)instead.